==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkHyperTreeGridSource.java <==
// java wrapper for vtkHyperTreeGridSource object
//

package vtk;
import vtk.*;

public class vtkHyperTreeGridSource extends vtkHyperTreeGridAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetMaximumLevel_2();
  public int GetMaximumLevel()
    { return GetMaximumLevel_2(); }

  private native void SetMaximumLevel_3(int id0);
  public void SetMaximumLevel(int id0)
    { SetMaximumLevel_3(id0); }

  private native void SetOrigin_4(double id0,double id1,double id2);
  public void SetOrigin(double id0,double id1,double id2)
    { SetOrigin_4(id0,id1,id2); }

  private native void SetOrigin_5(double id0[]);
  public void SetOrigin(double id0[])
    { SetOrigin_5(id0); }

  private native double[] GetOrigin_6();
  public double[] GetOrigin()
    { return GetOrigin_6(); }

  private native void SetGridScale_7(double id0,double id1,double id2);
  public void SetGridScale(double id0,double id1,double id2)
    { SetGridScale_7(id0,id1,id2); }

  private native void SetGridScale_8(double id0[]);
  public void SetGridScale(double id0[])
    { SetGridScale_8(id0); }

  private native double[] GetGridScale_9();
  public double[] GetGridScale()
    { return GetGridScale_9(); }

  private native void SetGridSize_10(int id0,int id1,int id2);
  public void SetGridSize(int id0,int id1,int id2)
    { SetGridSize_10(id0,id1,id2); }

  private native void SetTransposedRootIndexing_11(boolean id0);
  public void SetTransposedRootIndexing(boolean id0)
    { SetTransposedRootIndexing_11(id0); }

  private native boolean GetTransposedRootIndexing_12();
  public boolean GetTransposedRootIndexing()
    { return GetTransposedRootIndexing_12(); }

  private native void SetIndexingModeToKJI_13();
  public void SetIndexingModeToKJI()
    { SetIndexingModeToKJI_13(); }

  private native void SetIndexingModeToIJK_14();
  public void SetIndexingModeToIJK()
    { SetIndexingModeToIJK_14(); }

  private native void SetBranchFactor_15(int id0);
  public void SetBranchFactor(int id0)
    { SetBranchFactor_15(id0); }

  private native int GetBranchFactorMinValue_16();
  public int GetBranchFactorMinValue()
    { return GetBranchFactorMinValue_16(); }

  private native int GetBranchFactorMaxValue_17();
  public int GetBranchFactorMaxValue()
    { return GetBranchFactorMaxValue_17(); }

  private native int GetBranchFactor_18();
  public int GetBranchFactor()
    { return GetBranchFactor_18(); }

  private native void SetDimension_19(int id0);
  public void SetDimension(int id0)
    { SetDimension_19(id0); }

  private native int GetDimensionMinValue_20();
  public int GetDimensionMinValue()
    { return GetDimensionMinValue_20(); }

  private native int GetDimensionMaxValue_21();
  public int GetDimensionMaxValue()
    { return GetDimensionMaxValue_21(); }

  private native int GetDimension_22();
  public int GetDimension()
    { return GetDimension_22(); }

  private native void SetUseDescriptor_23(boolean id0);
  public void SetUseDescriptor(boolean id0)
    { SetUseDescriptor_23(id0); }

  private native boolean GetUseDescriptor_24();
  public boolean GetUseDescriptor()
    { return GetUseDescriptor_24(); }

  private native void UseDescriptorOn_25();
  public void UseDescriptorOn()
    { UseDescriptorOn_25(); }

  private native void UseDescriptorOff_26();
  public void UseDescriptorOff()
    { UseDescriptorOff_26(); }

  private native void SetUseMaterialMask_27(boolean id0);
  public void SetUseMaterialMask(boolean id0)
    { SetUseMaterialMask_27(id0); }

  private native boolean GetUseMaterialMask_28();
  public boolean GetUseMaterialMask()
    { return GetUseMaterialMask_28(); }

  private native void UseMaterialMaskOn_29();
  public void UseMaterialMaskOn()
    { UseMaterialMaskOn_29(); }

  private native void UseMaterialMaskOff_30();
  public void UseMaterialMaskOff()
    { UseMaterialMaskOff_30(); }

  private native void SetDescriptor_31(String id0);
  public void SetDescriptor(String id0)
    { SetDescriptor_31(id0); }

  private native String GetDescriptor_32();
  public String GetDescriptor()
    { return GetDescriptor_32(); }

  private native void SetMaterialMask_33(String id0);
  public void SetMaterialMask(String id0)
    { SetMaterialMask_33(id0); }

  private native String GetMaterialMask_34();
  public String GetMaterialMask()
    { return GetMaterialMask_34(); }

  private native void SetDescriptorBits_35(vtkBitArray id0);
  public void SetDescriptorBits(vtkBitArray id0)
    { SetDescriptorBits_35(id0); }

  private native long GetDescriptorBits_36();
  public vtkBitArray GetDescriptorBits() {
    long temp = GetDescriptorBits_36();

    if (temp == 0) return null;
    return (vtkBitArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetLevelZeroMaterialIndex_37(vtkIdTypeArray id0);
  public void SetLevelZeroMaterialIndex(vtkIdTypeArray id0)
    { SetLevelZeroMaterialIndex_37(id0); }

  private native void SetMaterialMaskBits_38(vtkBitArray id0);
  public void SetMaterialMaskBits(vtkBitArray id0)
    { SetMaterialMaskBits_38(id0); }

  private native long GetMaterialMaskBits_39();
  public vtkBitArray GetMaterialMaskBits() {
    long temp = GetMaterialMaskBits_39();

    if (temp == 0) return null;
    return (vtkBitArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetQuadric_40(vtkQuadric id0);
  public void SetQuadric(vtkQuadric id0)
    { SetQuadric_40(id0); }

  private native long GetQuadric_41();
  public vtkQuadric GetQuadric() {
    long temp = GetQuadric_41();

    if (temp == 0) return null;
    return (vtkQuadric)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetQuadricCoefficients_42(double id0[]);
  public void SetQuadricCoefficients(double id0[])
    { SetQuadricCoefficients_42(id0); }

  private native void GetQuadricCoefficients_43(double id0[]);
  public void GetQuadricCoefficients(double id0[])
    { GetQuadricCoefficients_43(id0); }

  private native int GetMTime_44();
  public int GetMTime()
    { return GetMTime_44(); }

  private native long ConvertDescriptorStringToBitArray_45(String id0);
  public vtkBitArray ConvertDescriptorStringToBitArray(String id0) {
    long temp = ConvertDescriptorStringToBitArray_45(id0);

    if (temp == 0) return null;
    return (vtkBitArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long ConvertMaterialMaskStringToBitArray_46(String id0);
  public vtkBitArray ConvertMaterialMaskStringToBitArray(String id0) {
    long temp = ConvertMaterialMaskStringToBitArray_46(id0);

    if (temp == 0) return null;
    return (vtkBitArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  public vtkHyperTreeGridSource() { super(); }

  public vtkHyperTreeGridSource(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-aarch64.pkg.tar.xz: vtk/vtkHyperTreeGridSource.java <==
// java wrapper for vtkHyperTreeGridSource object
//

package vtk;
import vtk.*;

public class vtkHyperTreeGridSource extends vtkHyperTreeGridAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetMaximumLevel_2();
  public int GetMaximumLevel()
    { return GetMaximumLevel_2(); }

  private native void SetMaximumLevel_3(int id0);
  public void SetMaximumLevel(int id0)
    { SetMaximumLevel_3(id0); }

  private native void SetOrigin_4(double id0,double id1,double id2);
  public void SetOrigin(double id0,double id1,double id2)
    { SetOrigin_4(id0,id1,id2); }

  private native void SetOrigin_5(double id0[]);
  public void SetOrigin(double id0[])
    { SetOrigin_5(id0); }

  private native double[] GetOrigin_6();
  public double[] GetOrigin()
    { return GetOrigin_6(); }

  private native void SetGridScale_7(double id0,double id1,double id2);
  public void SetGridScale(double id0,double id1,double id2)
    { SetGridScale_7(id0,id1,id2); }

  private native void SetGridScale_8(double id0[]);
  public void SetGridScale(double id0[])
    { SetGridScale_8(id0); }

  private native double[] GetGridScale_9();
  public double[] GetGridScale()
    { return GetGridScale_9(); }

  private native void SetGridSize_10(int id0,int id1,int id2);
  public void SetGridSize(int id0,int id1,int id2)
    { SetGridSize_10(id0,id1,id2); }

  private native void SetTransposedRootIndexing_11(boolean id0);
  public void SetTransposedRootIndexing(boolean id0)
    { SetTransposedRootIndexing_11(id0); }

  private native boolean GetTransposedRootIndexing_12();
  public boolean GetTransposedRootIndexing()
    { return GetTransposedRootIndexing_12(); }

  private native void SetIndexingModeToKJI_13();
  public void SetIndexingModeToKJI()
    { SetIndexingModeToKJI_13(); }

  private native void SetIndexingModeToIJK_14();
  public void SetIndexingModeToIJK()
    { SetIndexingModeToIJK_14(); }

  private native void SetBranchFactor_15(int id0);
  public void SetBranchFactor(int id0)
    { SetBranchFactor_15(id0); }

  private native int GetBranchFactorMinValue_16();
  public int GetBranchFactorMinValue()
    { return GetBranchFactorMinValue_16(); }

  private native int GetBranchFactorMaxValue_17();
  public int GetBranchFactorMaxValue()
    { return GetBranchFactorMaxValue_17(); }

  private native int GetBranchFactor_18();
  public int GetBranchFactor()
    { return GetBranchFactor_18(); }

  private native void SetDimension_19(int id0);
  public void SetDimension(int id0)
    { SetDimension_19(id0); }

  private native int GetDimensionMinValue_20();
  public int GetDimensionMinValue()
    { return GetDimensionMinValue_20(); }

  private native int GetDimensionMaxValue_21();
  public int GetDimensionMaxValue()
    { return GetDimensionMaxValue_21(); }

  private native int GetDimension_22();
  public int GetDimension()
    { return GetDimension_22(); }

  private native void SetUseDescriptor_23(boolean id0);
  public void SetUseDescriptor(boolean id0)
    { SetUseDescriptor_23(id0); }

  private native boolean GetUseDescriptor_24();
  public boolean GetUseDescriptor()
    { return GetUseDescriptor_24(); }

  private native void UseDescriptorOn_25();
  public void UseDescriptorOn()
    { UseDescriptorOn_25(); }

  private native void UseDescriptorOff_26();
  public void UseDescriptorOff()
    { UseDescriptorOff_26(); }

  private native void SetUseMaterialMask_27(boolean id0);
  public void SetUseMaterialMask(boolean id0)
    { SetUseMaterialMask_27(id0); }

  private native boolean GetUseMaterialMask_28();
  public boolean GetUseMaterialMask()
    { return GetUseMaterialMask_28(); }

  private native void UseMaterialMaskOn_29();
  public void UseMaterialMaskOn()
    { UseMaterialMaskOn_29(); }

  private native void UseMaterialMaskOff_30();
  public void UseMaterialMaskOff()
    { UseMaterialMaskOff_30(); }

  private native void SetDescriptor_31(String id0);
  public void SetDescriptor(String id0)
    { SetDescriptor_31(id0); }

  private native String GetDescriptor_32();
  public String GetDescriptor()
    { return GetDescriptor_32(); }

  private native void SetMaterialMask_33(String id0);
  public void SetMaterialMask(String id0)
    { SetMaterialMask_33(id0); }

  private native String GetMaterialMask_34();
  public String GetMaterialMask()
    { return GetMaterialMask_34(); }

  private native void SetDescriptorBits_35(vtkBitArray id0);
  public void SetDescriptorBits(vtkBitArray id0)
    { SetDescriptorBits_35(id0); }

  private native long GetDescriptorBits_36();
  public vtkBitArray GetDescriptorBits() {
    long temp = GetDescriptorBits_36();

    if (temp == 0) return null;
    return (vtkBitArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetLevelZeroMaterialIndex_37(vtkIdTypeArray id0);
  public void SetLevelZeroMaterialIndex(vtkIdTypeArray id0)
    { SetLevelZeroMaterialIndex_37(id0); }

  private native void SetMaterialMaskBits_38(vtkBitArray id0);
  public void SetMaterialMaskBits(vtkBitArray id0)
    { SetMaterialMaskBits_38(id0); }

  private native long GetMaterialMaskBits_39();
  public vtkBitArray GetMaterialMaskBits() {
    long temp = GetMaterialMaskBits_39();

    if (temp == 0) return null;
    return (vtkBitArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetQuadric_40(vtkQuadric id0);
  public void SetQuadric(vtkQuadric id0)
    { SetQuadric_40(id0); }

  private native long GetQuadric_41();
  public vtkQuadric GetQuadric() {
    long temp = GetQuadric_41();

    if (temp == 0) return null;
    return (vtkQuadric)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetQuadricCoefficients_42(double id0[]);
  public void SetQuadricCoefficients(double id0[])
    { SetQuadricCoefficients_42(id0); }

  private native void GetQuadricCoefficients_43(double id0[]);
  public void GetQuadricCoefficients(double id0[])
    { GetQuadricCoefficients_43(id0); }

  private native int GetMTime_44();
  public int GetMTime()
    { return GetMTime_44(); }

  private native long ConvertDescriptorStringToBitArray_45(String id0);
  public vtkBitArray ConvertDescriptorStringToBitArray(String id0) {
    long temp = ConvertDescriptorStringToBitArray_45(id0);

    if (temp == 0) return null;
    return (vtkBitArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long ConvertMaterialMaskStringToBitArray_46(String id0);
  public vtkBitArray ConvertMaterialMaskStringToBitArray(String id0) {
    long temp = ConvertMaterialMaskStringToBitArray_46(id0);

    if (temp == 0) return null;
    return (vtkBitArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkHyperTreeGridSource() { super(); }

  public vtkHyperTreeGridSource(long id) { super(id); }
  public native long   VTKInit();

}
